==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/init.js <==
// INIT script

/**
 * @brief : Initial class for IceWarp WebMail
 * @date  : 6.3.2006 19:01:49
 * @status: draft
 * @require: storage
 *

  ? check opener (for valid webmail window)
  - parse input vars to GLOBAL cookie_vars and url_vars
  - choose page ($page <- "login" <- cookie_vars <- url_vars)
  - check ID (!isset than page = login)
  - load settings (if doesnt exist in [opener.]dataset)
  - get Lang (depeds on settings)
*/

function cInit(){

	//registr function to global variable, must be here because it will be used
	window.oWM_INIT = this;
	
	// hide copyright box
	var eCopyright = document.getElementById('wm_copyright');
	if (eCopyright){
		eCopyright.style.display = 'none';
		eCopyright = null;
	}

	/* allowed content */
	this.allowed_cookie = {"sid":'',"frm":''};
	this.allowed_get    = {"page":'index',"debug":null,"frm":null,"sid":null,"user":"admin","pass":"asd"};   //odendat frm pouze pro debug

	/* name of main webmail cookie */
	this.wm_cookie = 'wm_cookie';

	/* parse cookies and get vars */
	this._vars = this.parse_vars();

	/* DEBUG */
	if (this._vars['debug']) window.api_debug = new cAPI_debug();

	/* load settings */
	storage.library('wm_storage');
	dataSet.add('storage','',WMStorage.get({'resources':['login_settings','layout_settings','forgot_settings','restrictions']}));

	/* get Language */
	storage.library('gw_others');
	storage.language(GWOthers.getItem('LAYOUT_SETTINGS','language'));
	this.page();
};

cInit.prototype.parse_vars = function() {
	var tmp,tmp2;

	/* cookie vars */
	tmp  = arrKeySlice(cookieManager.get(this.wm_cookie),this.allowed_cookie);
	/* get vars */
	tmp2 = arrKeySlice(parseURL(),this.allowed_get);

	/* join cookie & get vars */
	return arrConcat(tmp,tmp2);
};

/**
 * @brief: select PAGE from cookie
 *
 **/
cInit.prototype.page = function() {

	if (this._vars['sid']){
		//Add SID into dataset
		dataSet.add('main',['sid'],this._vars['sid']);
		//Save referrer, WM will be redirected back to this adress after logout
		if (document.referrer && document.referrer != document.location.href)
			dataSet.add('main',['referrer_url'],document.referrer);

		//start login sequence
		this._checkBrowserVersion()
		return;
	}
	
	switch (this._vars['frm']){
	// MAIN page
	case 'test':
					var a = auth.login({"username":this._vars['user'],"password":this._vars['pass']});
					gui._create('frm_login','login');
					break;
	// MAIN page
	case 'main':
					var a = auth.login({"username":this._vars['user'],"password":this._vars['pass']});
					gui._create('frm_main','frm_main');
					break;
	// LOGIN page
	default:
					gui._create('frm_login','frm_login','','',1);
	}
};


/**
 * Login sequence
 * @note: moved from frm_login (4.7.2007 10:58:11)
 **/
cInit.prototype._checkBrowserVersion = function () {
	switch (currentBrowser()) {
		case 'Mozilla':
		case 'MSIE7':
			this._continueLogin(); // do nothing, the browser is supported
			break;
		case 'MSIE6':

			//nacist "resources" do datasetu "storage"
			storage.library('wm_storage');
			storage.library('gw_others');

			//var oStorage = new wm_storage;
			dataSet.add('storage','',WMStorage.get({'resources':['login_data']}));

			//precist data z datasetu "storage"
			var iLastShow = parseInt(GWOthers.getItem('LOGIN_DATA', 'ie_6_warning_show_on'));

			var iNow = parseInt((new Date()).getTime());

			if (!Is.Number(iLastShow) || iLastShow <= iNow-(this._showIEWarningFrequency*86400000)){

				GWOthers.set('LOGIN_DATA',{'ie_6_warning_show_on':iNow},'storage');
				WMStorage.set({'resources':dataSet.get('storage')},'storage');

				gui._create('frm_confirm','frm_confirm','','', [this, '_continueLogin'], 'CONFIRMATION::BROWSER_WARNING_TITLE','CONFIRMATION::BROWSER_WARNING_TEXT_IE6');
			}
			else
				this._continueLogin();
			break;

		default:
			if (window.confirm(getLang('CONFIRMATION::BROWSER_WARNING_TEXT_UNSUPPORTED')))
				this._continueLogin();
			break;
	}
};

cInit.prototype._continueLogin = function () {
	var me = this;

	if (!gui.preloader){
		gui._create("preloader","obj_loader");
		gui.preloader._value(getLang('PRELOADER::LOADING_DATA'));
	}
	var accounts = new wm_accounts;
	var aAccounts = accounts.list();
	dataSet.add('accounts','',aAccounts);

	// [Sync] load of BIG JavaSript
    storage.library('javascript');
	// [Sync] Load resources
	storage.library('wm_storage');
	dataSet.add('storage','',WMStorage.get({'resources':[
											'gw_groups',
											'mail_settings_default',
											'mail_settings_general',
											'layout_settings',
											'calendar_settings',
											'default_calendar_settings',
											'cookie_settings',
											'default_reminder_settings',
											'default_folders',
											'signature',
											'restrictions']}));

    gui.preloader._value(getLang('PRELOADER::INDEXING'));
	for (var sAccId in aAccounts)
		if (aAccounts[sAccId] && aAccounts[sAccId]['PRIMARY']){
			// call the refresh via timeout so that the preloader is shown properly
			setTimeout(
			function(){accounts.refresh({'aid':sAccId},'folders',[sAccId],[me,'_updatePreloader']);
			},0);
			break;
		}
};

cInit.prototype._updatePreloader = function (sError) {

	if(sError){
        var state = cookieManager.get('LoginState');
        if (state === '0')
        	cookieManager.set('LoginState','1',30);

		alert(sError);

		window.location.href = window.location.href;
		return;
	}

	if (gui.preloader)
		gui.preloader._value(getLang('PRELOADER::LOADING_DATA'));

	var me = this;
	// call the refresh via timeout so that the preloader is updated properly
	setTimeout(function(){me._startMain();},0);
}

cInit.prototype._startMain = function () {
/*
	// [Sync] load of BIG JavaSript
    storage.library('javascript');

	// [Sync] Load resources
	storage.library('wm_storage');
	dataSet.add('storage','',WMStorage.get({'resources':['gw_groups','mail_settings_default','mail_settings_general','layout_settings','calendar_settings','cookie_settings','default_reminder_settings','default_folders','signature']}));
*/
	// [Async] Load style.css (marged css files)
	storage.css('style');

	// [Sync] Load Language
	storage.library('gw_others');
	storage.language(GWOthers.getItem('LAYOUT_SETTINGS', 'language'));

	// [Sync] preload of objects
	storage.preloadObj();

	if (gui.preloader)
		gui.preloader._destruct();

	// asynchronous preload of Templates and Libraries;
	gui._create("frm_main","frm_main","","",true);

	storage.preloadTpl();
};
///////////////////////////
function initgui(){
	new cInit();
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/init.js <==
// INIT script

/**
 * @brief : Initial class for IceWarp WebMail
 * @date  : 6.3.2006 19:01:49
 * @status: draft
 * @require: storage
 *

  ? check opener (for valid webmail window)
  - parse input vars to GLOBAL cookie_vars and url_vars
  - choose page ($page <- "login" <- cookie_vars <- url_vars)
  - check ID (!isset than page = login)
  - load settings (if doesnt exist in [opener.]dataset)
  - get Lang (depeds on settings)
*/

function cInit(){

	//registr function to global variable, must be here because it will be used
	window.oWM_INIT = this;
	
	// hide copyright box
	var eCopyright = document.getElementById('wm_copyright');
	if (eCopyright){
		eCopyright.style.display = 'none';
		eCopyright = null;
	}

	/* allowed content */
	this.allowed_cookie = {"sid":'',"frm":''};
	this.allowed_get    = {"page":'index',"debug":null,"frm":null,"sid":null,"user":"admin","pass":"asd"};   //odendat frm pouze pro debug

	/* name of main webmail cookie */
	this.wm_cookie = 'wm_cookie';

	/* parse cookies and get vars */
	this._vars = this.parse_vars();

	/* DEBUG */
	if (this._vars['debug']) window.api_debug = new cAPI_debug();

	/* load settings */
/*
	storage.library('wm_storage');
	dataSet.add('storage','',WMStorage.get({'resources':['skins','login_settings','layout_settings','forgot_settings','restrictions','signup_domains']}));
*/
	storage.library('gw_others');
	GWOthers.load(['skins','login_settings','layout_settings','forgot_settings','restrictions','signup_domains']);

	/* get Language */
	storage.language(GWOthers.getItem('LAYOUT_SETTINGS','language'));
	this.page();
};

cInit.prototype.parse_vars = function() {
	var tmp,tmp2;

	/* cookie vars */
	tmp  = arrKeySlice(cookieManager.get(this.wm_cookie),this.allowed_cookie);
	/* get vars */
	tmp2 = arrKeySlice(parseURL(),this.allowed_get);

	/* join cookie & get vars */
	return arrConcat(tmp,tmp2);
};

/**
 * @brief: select PAGE from cookie
 *
 **/
cInit.prototype.page = function() {

	if (this._vars['sid']){
		//Add SID into dataset
		dataSet.add('main',['sid'],this._vars['sid']);

		//Save referrer, WM will be redirected back to this adress after logout
		if (this._vars['ref'])
        	dataSet.add('main',['referrer_url'],this._vars['ref']);
		else
		if (document.referrer && document.referrer != document.location.href)
			dataSet.add('main',['referrer_url'],document.referrer);

		//start login sequence
		this._checkBrowserVersion()
		return;
	}
	
	switch (this._vars['frm']){
	// MAIN page
	case 'test':
					var a = auth.login({"username":this._vars['user'],"password":this._vars['pass']});
					gui._create('frm_login','login');
					break;
	// MAIN page
	case 'main':
					var a = auth.login({"username":this._vars['user'],"password":this._vars['pass']});
					gui._create('frm_main','frm_main');
					break;
	// LOGIN page
	default:
					gui._create('frm_login','frm_login','','',1);
	}
};


/**
 * Login sequence
 * @note: moved from frm_login (4.7.2007 10:58:11)
 **/
cInit.prototype._checkBrowserVersion = function () {
	switch (currentBrowser()) {
		case 'Mozilla':
		case 'MSIE7':
		case 'Safari':
			this._continueLogin(); // do nothing, the browser is supported
			break;
		case 'MSIE6':

			storage.library('wm_storage');
			storage.library('gw_others');

			if (GWOthers.getItem('RESTRICTIONS', 'disable_ie6warning')){
				this._continueLogin();
				break;
			}

			//nacist "resources" do datasetu "storage"
			dataSet.add('storage','',WMStorage.get({'resources':['login_data']}));

			//precist data z datasetu "storage"
			var iLastShow = parseInt(GWOthers.getItem('LOGIN_DATA', 'ie_6_warning_show_on'));

			var iNow = parseInt((new Date()).getTime());
			if (!Is.Number(iLastShow) || iLastShow <= iNow-(this._showIEWarningFrequency*86400000)){
				GWOthers.set('LOGIN_DATA',{'ie_6_warning_show_on':iNow},'storage');
				WMStorage.set({'resources':dataSet.get('storage')},'storage');

				gui._create('frm_confirm','frm_confirm','','', [this, '_continueLogin'], 'CONFIRMATION::BROWSER_WARNING_TITLE','CONFIRMATION::BROWSER_WARNING_TEXT_IE6');
			}
			else
				this._continueLogin();

			break;

		default:
			if (window.confirm(getLang('CONFIRMATION::BROWSER_WARNING_TEXT_UNSUPPORTED')))
				this._continueLogin();
			break;
	}
};

cInit.prototype._continueLogin = function () {
	var me = this;

	if (!gui.preloader){
		gui._create("preloader","obj_loader");
		gui.preloader._value(getLang('PRELOADER::LOADING_DATA'));
	}

	// [Sync] load of BIG JavaSript
    storage.library('javascript');

	// [Sync] Load resources
	GWOthers.load([	'skins',
					'gw_groups',
					'mail_settings_default',
					'mail_settings_general',
					'layout_settings',
					'calendar_settings',
					'default_calendar_settings',
					'cookie_settings',
					'default_reminder_settings',
					'default_folders',
					'signature',
					'restrictions',
					'personalities',
					'read_confirmation']);

	// [Sync] Load Language
	storage.language(GWOthers.getItem('LAYOUT_SETTINGS', 'language'));

	// get accounts
	var aAccounts = WMAccounts.list();
	dataSet.add('accounts','',aAccounts);

	// continue preloading
    gui.preloader._value(getLang('PRELOADER::INDEXING'));
	for (var sAccId in aAccounts)
		if (aAccounts[sAccId] && aAccounts[sAccId]['PRIMARY']){
			// call the refresh via timeout so that the preloader is shown properly
			setTimeout(
			function(){
			accounts.refresh({'aid':sAccId},'folders',[sAccId],[me,'_updatePreloader']);
			},0);
			break;
		}
};

cInit.prototype._updatePreloader = function (sError) {

	if(sError){
        var state = cookieManager.get('LoginState');
        if (state === '3')
        	cookieManager.set('LoginState','2',30);

		alert(sError);

		window.location.href = window.location.href;
		return;
	}

	if (gui.preloader)
		gui.preloader._value(getLang('PRELOADER::LOADING_DATA'));

	var me = this;
	// call the refresh via timeout so that the preloader is updated properly
	setTimeout(function(){me._startMain();},0);
}

cInit.prototype._startMain = function () {

	// [Async] Load style.css (marged css files)
	storage.css('style');

	// [Sync] preload of objects
	storage.preloadObj();

	if (gui.preloader)
		gui.preloader._destruct();

	// asynchronous preload of Templates and Libraries;
	gui._create("frm_main","frm_main","","",true);

	storage.preloadTpl();
};
///////////////////////////
function initgui(){
	new cInit();
};
